"use client";

import React, { useEffect, useState, Suspense } from "react";
import { useRouter, useSearchParams } from "next/navigation";
import { FaDownload, FaTelegramPlane, FaEnvelope } from "react-icons/fa"; // Icons
import Head from "next/head";
import AdSense from '@/app/components/AdSense';

const DownloadContent: React.FC = () => {
  const router = useRouter();
  const searchParams = useSearchParams();
  const [movieData, setMovieData] = useState<any>(null);
  const [loading, setLoading] = useState(true);

  const id = Number(searchParams.get("id"));  // Convert the ID to a number to match the JSON data
  const movieType = searchParams.get("type"); // 'movie' or 'tv'
  const releaseYear = searchParams.get("year"); // Get the releaseYear from the URL

  useEffect(() => {
    if (!id || !movieType || !releaseYear) {
      router.push("/");
      return;
    }

    const fetchDownloadLinks = async () => {
      try {
        // Fetch the correct year's JSON file dynamically
        const response = await fetch(`/json/${releaseYear}.json`);
        const data = await response.json();

        const movieInfo = data.find((item: any) => item.id === id && item.type === movieType);
        if (movieInfo) {
          // Filter out any links that have a URL of "#"
          const validDownloads = movieInfo.downloads.filter((download: any) => download.url !== "#");

          // Update movieData with valid downloads only
          setMovieData({ ...movieInfo, downloads: validDownloads });
        } else {
          setMovieData(null);
        }
      } catch (error) {
        console.error("Error fetching download links:", error);
        setMovieData(null);
      } finally {
        setLoading(false);
      }
    };

    fetchDownloadLinks();
  }, [id, movieType, releaseYear, router]);

  const handleReport = () => {
    if (movieData) {
      const subject = encodeURIComponent(`Fix ${movieData.title}`);
      const body = encodeURIComponent(
        `Hello,\n\nThe download link for "${movieData.title}" is not working. Could you please fix it?\n\nThank you!`
      );
      window.location.href = `mailto:support@example.com?subject=${subject}&body=${body}`;
    }
  };

  const handleTelegramReport = () => {
    window.open("https://t.me/delgomoviesdiscussion", "_blank");
  };

  if (loading) {
    return (
      <div className="flex flex-col items-center justify-center h-screen">
        <p className="text-lg text-white">Loading download links... Please wait.</p>
      </div>
    );
  }

  if (!movieData || movieData.downloads.length === 0) {
    return (
      <div className="flex flex-col items-center justify-center h-screen text-center">
        <Head>
          <title>Download Links Unavailable - Delgor</title>
          <meta name="description" content="Sorry, we couldn't find any valid download links. Please report the issue for quick resolution." />
          <link rel="canonical" href="https://www.delgor.com/download" />
          <meta property="og:title" content="Download Links Unavailable - Delgor" />
          <meta property="og:description" content="Sorry, we couldn't find any valid download links. Please report the issue for quick resolution." />
          <meta property="og:type" content="website" />
          <meta property="og:url" content="https://www.delgor.com/download" />
          <meta property="og:image" content="/images/ogdelgor.png" /> {/* Replace with your actual OG image */}
          <meta property="og:image:alt" content="Delgor Download Links Unavailable" />
          <meta property="og:site_name" content="Delgor" />
        </Head>
        <div className="animate-shake text-6xl mb-4">
          <span role="img" aria-label="sad emoji">
            😢
          </span>
        </div>
        <p className="text-lg text-white mb-4">
          Sorry, we couldn't find any valid download links for "{movieData?.title || "this item"}".
          <br />
          Please report the issue, and we'll get it fixed within a few hours.
        </p>
        <div className="space-y-4">
          <button
            onClick={handleReport}
            className="flex items-center justify-center px-6 py-2 bg-red-500 text-white rounded hover:bg-red-600"
          >
            <FaEnvelope className="mr-2" /> Report via Email
          </button>
          <button
            onClick={handleTelegramReport}
            className="flex items-center justify-center px-6 py-2 bg-blue-500 text-white rounded hover:bg-blue-600"
          >
            <FaTelegramPlane className="mr-2" /> Report via Telegram / Join Telegram
          </button>
        </div>
        {/* AdSense Ad at the Bottom of the Error Page */}
        <div className="w-full my-4">
          <AdSense />
        </div>
      </div>
    );
  }

  return (
    <>
      <Head>
        <title>{`Download ${movieType === "movie" ? "Movie" : "TV Series"}: ${movieData.title} - Delgor`}</title>
        <meta name="description" content={`Download ${movieData.title} on Delgor. Multiple quality options available.`} />
        <link rel="canonical" href={`https://www.delgor.com/download?id=${movieData.id}&type=${movieType}`} />
        <meta property="og:title" content={`Download ${movieType === "movie" ? "Movie" : "TV Series"}: ${movieData.title} - Delgor`} />
        <meta property="og:description" content={`Download ${movieData.title} on Delgor. Multiple quality options available.`} />
        <meta property="og:type" content="website" />
        <meta property="og:url" content={`https://www.delgor.com/download?id=${movieData.id}&type=${movieType}`} />
        <meta property="og:image" content="/images/ogdelgor.png" /> {/* Replace with your actual OG image */}
        <meta property="og:image:alt" content={`Download ${movieData.title}`} />
        <meta property="og:site_name" content="Delgor" />
        {/* Structured Data for the Download Page */}
        <script type="application/ld+json">
          {JSON.stringify({
            "@context": "https://schema.org",
            "@type": movieType === "movie" ? "Movie" : "TVSeries",
            "name": movieData.title,
            "description": `Download ${movieData.title} on Delgor. Multiple quality options available.`,
            "url": `https://www.delgor.com/download?id=${movieData.id}&type=${movieType}`,
            "image": "/images/ogdelgor.png",
          })}
        </script>
      </Head>
      <div className="container mx-auto p-4 mt-16">
        {/* AdSense Ad at the Top */}
        <div className="w-full my-4">
          <AdSense />
        </div>

        <h1 className="text-3xl text-white mb-6">Download Links for "{movieData.title}"</h1>

        {/* Report buttons for broken links */}
        <div className="flex space-x-4 mb-8 animate-fadeInUp">
          <button
            onClick={handleReport}
            className="flex items-center justify-center px-4 py-2 bg-yellow-500 text-white rounded hover:bg-yellow-600"
          >
            <FaEnvelope className="mr-2" /> Report Broken Link via Email
          </button>
          <button
            onClick={handleTelegramReport}
            className="flex items-center justify-center px-4 py-2 bg-blue-500 text-white rounded hover:bg-blue-600"
          >
            <FaTelegramPlane className="mr-2" /> Report via Telegram / Join Telegram
          </button>
        </div>

        {/* Download links */}
        <ul className="space-y-4 mb-24">
          {movieData.downloads.map((download: any, index: number) => (
            <React.Fragment key={index}>
              {index > 0 && index % 8 === 0 && (
                <div className="w-full my-4">
                  <AdSense />
                </div>
              )}
              <li className="animate-fadeInUp">
                <a
                  href={download.url}
                  target="_blank"
                  rel="noopener noreferrer"
                  className="flex items-center justify-center px-6 py-3 bg-red-500 text-white rounded hover:bg-red-600"
                >
                  <FaDownload className="mr-2" /> {download.label}
                </a>
              </li>
            </React.Fragment>
          ))}
          {/* Spacer to prevent the navbar from covering buttons */}
          <div className="h-24"></div>
        </ul>

        {/* AdSense Ad at the Bottom */}
        <div className="w-full my-4">
          <AdSense />
        </div>
      </div>
    </>
  );
};

export default function DownloadPageWrapper() {
  return (
    <Suspense fallback={<div>Loading...</div>}>
      <DownloadContent />
    </Suspense>
  );
}
